==> bigloo2.0a.tar.gz: bigloo2.0a/comptime/Cnst/walk.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.9/Cnst/walk.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Feb  3 09:46:40 1995                          */
;*    Last change :  Fri Aug  9 08:25:41 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    The `constant compilation'                                       */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module cnst_walk
   (include "Engine/pass.sch")
   (import  tools_shape
	    tools_error
	    engine_param
	    type_type
	    ast_var
	    ast_node
	    ast_remove
	    cnst_alloc
	    cnst_cache
	    cnst_node
	    cnst_initialize)
   (export  (cnst-walk! globals)))

;*---------------------------------------------------------------------*/
;*    cnst-walk! ...                                                   */
;*---------------------------------------------------------------------*/
(define (cnst-walk! globals)
   (pass-prelude "Cnst" start-cnst-cache! start-cnst-alloc! unsafe!)
   (verbose 2 "      [" *init-mode* #\] #\Newline)
   (for-each (lambda (global)
		(enter-function (global-id global))
		(let* ((fun      (global-value global))
		       (new-body (cnst! (sfun-body fun))))
		   (sfun-body-set! fun new-body))
		(leave-function))
	     globals)
   (pass-postlude (remove-var 'cnst (append (initialize-ast) globals))
		  stop-cnst-alloc!
		  safe!))

;*---------------------------------------------------------------------*/
;*    unsafe! ...                                                      */
;*---------------------------------------------------------------------*/
(define (unsafe!)
   (set! *old-unsafe-type* *unsafe-type*)
   (set! *unsafe-type* #t)
   (set! *old-unsafe-arity* *unsafe-arity*)
   (set! *unsafe-arity* #t)
   (set! *old-unsafe-range* *unsafe-range*)
   (set! *unsafe-range* #t)
   (set! *old-unsafe-struct* *unsafe-struct*)
   (set! *unsafe-struct* #t)
   (set! *old-unsafe-version* *unsafe-version*)
   (set! *unsafe-version* #t))

;*---------------------------------------------------------------------*/
;*    safe! ...                                                        */
;*---------------------------------------------------------------------*/
(define (safe!)
   (set! *unsafe-type* *old-unsafe-type*)
   (set! *unsafe-arity* *old-unsafe-arity*)
   (set! *unsafe-range* *old-unsafe-range*)
   (set! *unsafe-struct* *old-unsafe-struct*)
   (set! *unsafe-version* *old-unsafe-version*))

;*---------------------------------------------------------------------*/
;*    old-unsafes                                                      */
;*---------------------------------------------------------------------*/
(define *old-unsafe-type*    #f)
(define *old-unsafe-arity*   #f)
(define *old-unsafe-range*   #f)
(define *old-unsafe-struct*  #f)
(define *old-unsafe-version* #f)

==> bigloo-4.5b.tar.gz: bigloo-4.5b/comptime/Cnst/walk.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/bigloo/comptime/Cnst/walk.scm        */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Feb  3 09:46:40 1995                          */
;*    Last change :  Fri Jun  3 14:19:08 2022 (serrano)                */
;*    Copyright   :  1995-2022 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    The `constant compilation'                                       */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module cnst_walk
   (include "Engine/pass.sch"
            "Tools/trace.sch")
   (import  tools_shape
	    tools_error
	    engine_param
	    type_type
	    ast_var
	    ast_node
	    ast_remove
	    cnst_alloc
	    cnst_cache
	    cnst_node
	    cnst_initialize)
   (export  (cnst-walk! globals)))

;*---------------------------------------------------------------------*/
;*    cnst-walk! ...                                                   */
;*---------------------------------------------------------------------*/
(define (cnst-walk! globals)
   (pass-prelude "Cnst" start-cnst-cache! start-cnst-alloc! unsafe!)
   (verbose 2 "      [" *init-mode* #\] #\Newline)
   (for-each (lambda (global)
		(trace cnst (shape global) #\Newline)
		(enter-function (global-id global))
		(let* ((fun (global-value global))
		       (new-body (cnst! (sfun-body fun))))
		   (sfun-body-set! fun new-body))
		(leave-function))
      globals)
   (let ((ast (append (initialize-ast) globals)))
      (pass-postlude (remove-var 'cnst ast)
	 stop-cnst-alloc!
	 safe!)))

;*---------------------------------------------------------------------*/
;*    unsafe! ...                                                      */
;*---------------------------------------------------------------------*/
(define (unsafe!)
   (set! *old-unsafe-type* *unsafe-type*)
   (set! *unsafe-type* #t)
   (set! *old-unsafe-arity* *unsafe-arity*)
   (set! *unsafe-arity* #t)
   (set! *old-unsafe-range* *unsafe-range*)
   (set! *unsafe-range* #t)
   (set! *old-unsafe-struct* *unsafe-struct*)
   (set! *unsafe-struct* #t)
   (set! *old-unsafe-version* *unsafe-version*)
   (set! *unsafe-version* #t))

;*---------------------------------------------------------------------*/
;*    safe! ...                                                        */
;*---------------------------------------------------------------------*/
(define (safe!)
   (set! *unsafe-type* *old-unsafe-type*)
   (set! *unsafe-arity* *old-unsafe-arity*)
   (set! *unsafe-range* *old-unsafe-range*)
   (set! *unsafe-struct* *old-unsafe-struct*)
   (set! *unsafe-version* *old-unsafe-version*))

;*---------------------------------------------------------------------*/
;*    old-unsafes                                                      */
;*---------------------------------------------------------------------*/
(define *old-unsafe-type* #f)
(define *old-unsafe-arity* #f)
(define *old-unsafe-range* #f)
(define *old-unsafe-struct* #f)
(define *old-unsafe-version* #f)
